@@ -108,10 +108,9 @@ func (a *Aliases) Define(gvr string, aliases ...string) {
 	}
 
 	for _, alias := range aliases {
-		if _, ok := a.Alias[alias]; ok {
-			continue
+		if _, ok := a.Alias[alias]; !ok && alias != "" {
+			a.Alias[alias] = gvr
 		}
-		a.Alias[alias] = gvr
 	}
 }
 
@@ -177,7 +176,8 @@ func (a *Aliases) loadDefaultAliases() {
 	a.declare("help", "h", "?")
 	a.declare("quit", "q", "q!", "qa", "Q")
 	a.declare("aliases", "alias", "a")
-	a.declare("popeye", "pop")
+	// !!BOZO!!
+	// a.declare("popeye", "pop")
 	a.declare("helm", "charts", "chart", "hm")
 	a.declare("dir", "d")
 	a.declare("contexts", "context", "ctx")
