@@ -45,16 +45,6 @@ func defaultFGNodeShell() bool {
 	return false
 }
 
-// InList check if string is in a collection of strings.
-func InList(ll []string, n string) bool {
-	for _, l := range ll {
-		if l == n {
-			return true
-		}
-	}
-	return false
-}
-
 // EnsureDirPath ensures a directory exist from the given path.
 func EnsureDirPath(path string, mod os.FileMode) error {
 	return EnsureFullPath(filepath.Dir(path), mod)
