@@ -91,7 +91,7 @@ func (s *StatefulSet) Restart(ctx context.Context, path string) error {
 		s.Forwarders().Kill(client.FQN(p.Namespace, p.Name))
 	}
 
-	auth, err := s.Client().CanI(sts.Namespace, "apps/v1/statefulsets", n, []string{client.PatchVerb})
+	auth, err := s.Client().CanI(sts.Namespace, "apps/v1/statefulsets", n, client.PatchAccess)
 	if err != nil {
 		return err
 	}
@@ -152,7 +152,7 @@ func (s *StatefulSet) TailLogs(ctx context.Context, opts *LogOptions) ([]LogChan
 		return nil, errors.New("expecting StatefulSet resource")
 	}
 	if sts.Spec.Selector == nil || len(sts.Spec.Selector.MatchLabels) == 0 {
-		return nil, fmt.Errorf("No valid selector found on StatefulSet %s", opts.Path)
+		return nil, fmt.Errorf("no valid selector found on statefulset: %s", opts.Path)
 	}
 
 	return podLogs(ctx, sts.Spec.Selector.MatchLabels, opts)
@@ -291,7 +291,7 @@ func (s *StatefulSet) GetPodSpec(path string) (*v1.PodSpec, error) {
 // SetImages sets container images.
 func (s *StatefulSet) SetImages(ctx context.Context, path string, imageSpecs ImageSpecs) error {
 	ns, n := client.Namespaced(path)
-	auth, err := s.Client().CanI(ns, "apps/v1/statefulset", n, []string{client.PatchVerb})
+	auth, err := s.Client().CanI(ns, "apps/v1/statefulset", n, client.PatchAccess)
 	if err != nil {
 		return err
 	}
