@@ -32,7 +32,7 @@ func (s *Service) TailLogs(ctx context.Context, opts *LogOptions) ([]LogChan, er
 	if err != nil {
 		return nil, err
 	}
-	if svc.Spec.Selector == nil || len(svc.Spec.Selector) == 0 {
+	if len(svc.Spec.Selector) == 0 {
 		return nil, fmt.Errorf("no valid selector found on Service %s", opts.Path)
 	}
 
@@ -51,7 +51,7 @@ func (s *Service) Pod(fqn string) (string, error) {
 
 // GetInstance returns a service instance.
 func (s *Service) GetInstance(fqn string) (*v1.Service, error) {
-	o, err := s.GetFactory().Get(s.gvr.String(), fqn, true, labels.Everything())
+	o, err := s.getFactory().Get(s.gvrStr(), fqn, true, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
