@@ -6,6 +6,8 @@ package model1
 import (
 	"fmt"
 	"sort"
+
+	"github.com/rs/zerolog/log"
 )
 
 type ReRangeFn func(int, RowEvent) bool
@@ -272,6 +274,14 @@ func (r *RowEvents) Sort(ns string, sortCol int, isDuration, numCol, isCapacity,
 	r.reindex()
 }
 
+// For debguging...
+func (re RowEvents) Dump(msg string) {
+	log.Debug().Msg(msg)
+	for _, r := range re.events {
+		log.Debug().Msgf("!!YO!! %#v", r)
+	}
+}
+
 // ----------------------------------------------------------------------------
 
 // RowEventSorter sorts row events by a given colon.
