@@ -5,7 +5,6 @@ package view
 
 import (
 	"context"
-	"strings"
 
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/client"
@@ -63,13 +62,12 @@ func (a *Alias) gotoCmd(evt *tcell.EventKey) *tcell.EventKey {
 		return a.GetTable().activateCmd(evt)
 	}
 
-	r, _ := a.GetTable().GetSelection()
-	if r != 0 {
-		s := ui.TrimCell(a.GetTable().SelectTable, r, 1)
-		tokens := strings.Split(s, ",")
-		a.App().gotoResource(tokens[0], "", true, true)
-		return nil
+	path := a.GetTable().GetSelectedItem()
+	if path == "" {
+		return evt
 	}
+	gvr := client.NewGVR(path)
+	a.App().gotoResource(gvr.AsResourceName(), "", true, true)
 
-	return evt
+	return nil
 }
