@@ -13,18 +13,17 @@ import (
 	"github.com/anchore/clio"
 	"github.com/anchore/grype/cmd/grype/cli/options"
 	"github.com/anchore/grype/grype"
-	"github.com/anchore/grype/grype/db"
 	"github.com/anchore/grype/grype/db/legacy/distribution"
-	"github.com/anchore/grype/grype/matcher"
-	"github.com/anchore/grype/grype/matcher/dotnet"
-	"github.com/anchore/grype/grype/matcher/golang"
-	"github.com/anchore/grype/grype/matcher/java"
-	"github.com/anchore/grype/grype/matcher/javascript"
-	"github.com/anchore/grype/grype/matcher/python"
-	"github.com/anchore/grype/grype/matcher/ruby"
-	"github.com/anchore/grype/grype/matcher/stock"
+	v5 "github.com/anchore/grype/grype/db/v5"
+	"github.com/anchore/grype/grype/db/v5/matcher"
+	"github.com/anchore/grype/grype/db/v5/matcher/dotnet"
+	"github.com/anchore/grype/grype/db/v5/matcher/golang"
+	"github.com/anchore/grype/grype/db/v5/matcher/java"
+	"github.com/anchore/grype/grype/db/v5/matcher/javascript"
+	"github.com/anchore/grype/grype/db/v5/matcher/python"
+	"github.com/anchore/grype/grype/db/v5/matcher/ruby"
+	"github.com/anchore/grype/grype/db/v5/matcher/stock"
 	"github.com/anchore/grype/grype/pkg"
-	"github.com/anchore/grype/grype/store"
 	"github.com/anchore/grype/grype/vex"
 	"github.com/anchore/syft/syft"
 	"github.com/derailed/k9s/internal/config"
@@ -41,8 +40,7 @@ const (
 )
 
 type imageScanner struct {
-	store       *store.Store
-	dbCloser    *db.Closer
+	store       *v5.ProviderStore
 	dbStatus    *distribution.Status
 	opts        *options.Grype
 	scans       Scans
@@ -90,8 +88,8 @@ func (s *imageScanner) Init(name, version string) {
 	s.opts.GenerateMissingCPEs = true
 
 	var err error
-	s.store, s.dbStatus, s.dbCloser, err = grype.LoadVulnerabilityDB(
-		s.opts.DB.ToCuratorConfig(),
+	s.store, s.dbStatus, err = grype.LoadVulnerabilityDB(
+		s.opts.DB.ToLegacyCuratorConfig(),
 		s.opts.DB.AutoUpdate,
 	)
 	if err != nil {
@@ -112,9 +110,9 @@ func (s *imageScanner) Stop() {
 	s.mx.RLock()
 	defer s.mx.RUnlock()
 
-	if s.dbCloser != nil {
-		s.dbCloser.Close()
-		s.dbCloser = nil
+	if s.store != nil {
+		s.store.Close()
+		s.store = nil
 	}
 }
 
@@ -162,7 +160,7 @@ func (s *imageScanner) scanWorker(ctx context.Context, img string) {
 	}
 }
 
-func (s *imageScanner) scan(ctx context.Context, img string, sc *Scan) error {
+func (s *imageScanner) scan(_ context.Context, img string, sc *Scan) error {
 	defer func(t time.Time) {
 		log.Debug().Msgf("ScanTime %q: %v", img, time.Since(t))
 	}(time.Now())
